@@ -2,12 +2,12 @@
 
 import typing
 from abc import ABCMeta, abstractmethod
-from urllib.parse import urljoin
+from urllib.parse import urljoin, urlparse
 
 import arrow
 import requests
 
-from frontegg._mixins import AuditsClientMixin
+from frontegg._mixins import AuditsClientMixin, SSOClientMixin
 from frontegg.permissions import FronteggPermissions, validate_permissions
 
 RequestT = typing.TypeVar('RequestT')
@@ -132,7 +132,8 @@ class BaseFronteggClient(typing.Generic[RequestT], metaclass=ABCMeta):
                 method: str,
                 json: typing.Optional[dict] = None,
                 params: typing.Optional[dict] = None,
-                tenant_id: typing.Optional[str] = None) -> requests.Response:
+                tenant_id: typing.Optional[str] = None,
+                host: typing.Optional[str] = None) -> requests.Response:
         """Perform a request to Frontegg's API.
 
         :param endpoint: The endpoint to perform the request to.
@@ -160,19 +161,22 @@ class BaseFronteggClient(typing.Generic[RequestT], metaclass=ABCMeta):
 
         headers = {
             'x-access-token': self.api_token,
+            'frontegg-vendor-host': host
+
         }
         if tenant_id:
             headers['frontegg-tenant-id'] = tenant_id
         if user_id:
             headers['frontegg-user-id'] = user_id
 
-        
         return self.session.request(
-                method,
-                urljoin(self.base_url, endpoint),
-                headers=headers,
-                json=json,
-                params=params)
+            method,
+            urljoin(self.base_url, endpoint),
+            allow_redirects=False,
+            headers=headers,
+            json=json,
+            params=params)
+
 
 class FronteggRESTClient(BaseFronteggClient[None]):
     """A standalone Frontegg REST client."""
@@ -180,7 +184,8 @@ class FronteggRESTClient(BaseFronteggClient[None]):
     def __init__(self,
                  client_id: str,
                  api_key: str,
-                 context_callback: typing.Optional[typing.Callable[[RequestT], FronteggContext]] = None,
+                 context_callback: typing.Optional[typing.Callable[[
+                     RequestT], FronteggContext]] = None,
                  base_url: str = 'https://api.frontegg.com/',
                  authentication_service_url: typing.Optional[str] = None) -> None:
         """Initialize the Frontegg REST client.
@@ -213,15 +218,17 @@ class FronteggRESTClient(BaseFronteggClient[None]):
         return None
 
 
-class FronteggClient(AuditsClientMixin):
+class FronteggClient(SSOClientMixin, AuditsClientMixin):
     def __init__(self,
                  client_id: str,
                  api_key: str,
-                 context_callback: typing.Optional[typing.Callable[[RequestT], FronteggContext]] = None,
+                 context_callback: typing.Optional[typing.Callable[[
+                     RequestT], FronteggContext]] = None,
                  base_url: str = 'https://api.frontegg.com/',
                  authentication_service_url: typing.Optional[str] = None,
                  audits_service_url: typing.Optional[str] = None,
-                 metadata_service_url: typing.Optional[str] = None) -> None:
+                 metadata_service_url: typing.Optional[str] = None,
+                 team_service_url: typing.Optional[str] = None) -> None:
         """Initialize the Frontegg client.
 
         :param client_id: The client ID provided to you by Frontegg.
@@ -230,26 +237,31 @@ class FronteggClient(AuditsClientMixin):
         :param base_url: The base URL of the API.
         :param authentication_service_url: The URL for authenticating against Frontegg.
         """
-        self._client = FronteggRESTClient(client_id, api_key, context_callback, base_url, authentication_service_url)
+        self._client = FronteggRESTClient(
+            client_id, api_key, context_callback, base_url, authentication_service_url)
 
         if audits_service_url:
             self._audits_service_url = audits_service_url
         else:
-            self._audits_service_url = urljoin(
-                base_url, '/audits')
+            self._audits_service_url = urljoin(base_url, '/audits')
 
         if metadata_service_url:
             self._metadata_service_url = metadata_service_url
         else:
-            self._metadata_service_url = urljoin(
-                base_url, '/metadata')
+            self._metadata_service_url = urljoin(base_url, '/metadata')
+
+        if team_service_url:
+            self._team_service_url = team_service_url
+        else:
+            self._team_service_url = urljoin(base_url, '/team')
 
     @property
     def _config(self) -> dict:
         return {
             'FRONTEGG_AUDITS_SERVICE_URL': self._audits_service_url,
-            'FRONTEGG_METADATA_SERVICE_URL': self._metadata_service_url
+            'FRONTEGG_METADATA_SERVICE_URL': self._metadata_service_url,
+            'FRONTEGG_TEAM_SERVICE_URL': self._team_service_url
         }
 
 
-__all__ = ('BaseFronteggClient', 'FronteggRESTClient')
+__all__ = ('BaseFronteggClient', 'FronteggRESTClient', 'FronteggClient')
