@@ -2,14 +2,14 @@
 
 import os
 import typing
-from urllib.parse import urljoin
+from urllib.parse import urljoin, urlparse
 
 import requests
 from flask import (Blueprint, Flask, Request, current_app, make_response,
                    request)
 from werkzeug.datastructures import Headers
 
-from frontegg._mixins import AuditsClientMixin
+from frontegg._mixins import AuditsClientMixin, IdentityClientMixin
 from frontegg.client import BaseFronteggClient
 from frontegg.permissions import ForbiddenRequest
 
@@ -35,13 +35,16 @@ class FronteggFlaskClient(BaseFronteggClient[Request]):
         :raises requests.HTTPError: If the Frontegg API responds with an HTTP error code, this exception is raised.
         """
 
+        o = urlparse(request.base_url)
+        hostname = o.hostname
+
         requestJson = None
         if (request.is_json == True and request.data != b''):
             requestJson = request.json
-        return self.request(endpoint, request.method, json=requestJson, params=request.args)
+        return self.request(endpoint, request.method, json=requestJson, params=request.args, host=hostname)
 
 
-class Frontegg(AuditsClientMixin):
+class Frontegg(AuditsClientMixin, IdentityClientMixin):
     """Frontegg Flask Extension.
 
     >>> from flask import Flask
@@ -113,6 +116,12 @@ class Frontegg(AuditsClientMixin):
         app.config.setdefault('FRONTEGG_TEAM_SERVICE_URL',
                               frontegg_team_service_url)
 
+        frontegg_identity_service_url = os.environ.get('FRONTEGG_IDENTITY_SERVICE_URL',
+                                                   urljoin(frontegg_api_gateway_url,
+                                                           '/identity'))
+        app.config.setdefault('FRONTEGG_IDENTITY_SERVICE_URL',
+                              frontegg_identity_service_url)
+
         frontegg_blueprint = Blueprint(
             'frontegg', __name__, url_prefix='/frontegg')
 
@@ -122,13 +131,14 @@ class Frontegg(AuditsClientMixin):
             proxy_response = self._client.proxy_request(endpoint)
 
             try:
+                headersWithoutCors = {k: v for k, v in proxy_response.headers.items() if not k.lower().startswith('access-control')}
                 response = make_response(
-                    proxy_response.content, proxy_response.status_code)
-                response_headers = {
-                    **response.headers,
-                    **{key.title(): value for key, value in proxy_response.headers.items()}
-                }
-                response.headers = Headers(response_headers)
+                    proxy_response.content, proxy_response.status_code, headersWithoutCors)
+                
+                # response_headers = {
+                #     **response.headers,
+                #     **{key.title(): value for key, value in proxy_response.headers.items()}
+                # }
                 return response
             except ForbiddenRequest:
                 return {'message': "Forbidden"}, 403
